@@ -27,7 +27,7 @@ class ForumAdmin(admin.ModelAdmin):
          ),
         (_('Additional options'), {
                 'classes': ('collapse',),
-                'fields': ('position', 'description', 'post_count', 'moderators')
+                'fields': ('position', 'description', 'slug', 'post_count', 'moderators')
                 }
             ),
         )
