@@ -11,8 +11,8 @@ PYBB_SIGNATURE_MAX_LINES = 3
 PYBB_QUICK_TOPICS_NUMBER = 10
 PYBB_QUICK_POSTS_NUMBER = 10
 PYBB_READ_TIMEOUT = 3600 * 24 * 7 # seconds
-PYBB_POST_AUTOJOIN_ENABLED = True
-PYBB_POST_AUTOJOIN_TIMEOUT = 60 * 60 # seconds
+#PYBB_POST_AUTOJOIN_ENABLED = True
+#PYBB_POST_AUTOJOIN_TIMEOUT = 60 * 60 # seconds
 PYBB_DEFAULT_MARKUP = 'bbcode'
 PYBB_FREEZE_FIRST_POST = True
 PYBB_ADMIN_URL = '/admin/'
