@@ -1,7 +1,6 @@
 from datetime import datetime
 import os.path
 import random
-from BeautifulSoup import BeautifulSoup
 import traceback
 try:
 	from hashlib import md5
@@ -11,35 +10,11 @@ import urllib
 
 from django.utils.translation import check_for_language
 from django import forms
-from django.template.defaultfilters import urlize as django_urlize
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.conf import settings
 from django.contrib.sites.models import Site
 
 
-def urlize(data):
-    """
-    Urlize plain text links in the HTML contents.
-
-    Do not urlize content of A and CODE tags.
-    """
-
-    soup = BeautifulSoup(data)
-    for chunk in soup.findAll(text=True):
-        islink = False
-        ptr = chunk.parent
-        while ptr.parent:
-            if ptr.name == 'a' or ptr.name == 'code':
-                islink = True
-                break
-            ptr = ptr.parent
-
-        if not islink:
-            chunk = chunk.replaceWith(django_urlize(unicode(chunk)))
-
-    return unicode(soup)
-
-
 def quote_text(text, markup, username=""):
     """
     Quote message using selected markup.
